@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2003 Andreas Gungl <a.gungl@gmx.de>
-    SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2012-2024 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-only
 */
@@ -203,7 +203,7 @@ void FilterLogDialog::readConfig()
         FilterLog::instance()->setMaxLogSize(maxLogSize);
     }
 
-    KConfigGroup geometryGroup(config, QStringLiteral("Geometry"));
+    KConfigGroup geometryGroup(KSharedConfig::openConfig(), QStringLiteral("Geometry"));
     const QSize size = geometryGroup.readEntry("filterLogSize", QSize(600, 400));
     if (size.isValid()) {
         resize(size);
