@@ -152,9 +152,7 @@ KMCommand::KMCommand(QWidget *parent)
 }
 
 KMCommand::KMCommand(QWidget *parent, const Akonadi::Item &msg)
-    : mDeletesItself(false)
-    , mEmitsCompletedItself(false)
-    , mParent(parent)
+    : KMCommand(parent)
 {
     if (msg.isValid() || msg.hasPayload<KMime::Message::Ptr>()) {
         mMsgList.append(msg);
@@ -162,11 +160,9 @@ KMCommand::KMCommand(QWidget *parent, const Akonadi::Item &msg)
 }
 
 KMCommand::KMCommand(QWidget *parent, const Akonadi::Item::List &msgList)
-    : mDeletesItself(false)
-    , mEmitsCompletedItself(false)
-    , mParent(parent)
-    , mMsgList(msgList)
+    : KMCommand(parent)
 {
+    mMsgList = msgList;
 }
 
 KMCommand::~KMCommand() = default;
@@ -273,6 +269,16 @@ Akonadi::ItemFetchJob *KMCommand::createFetchJob(const Akonadi::Item::List &item
     return new Akonadi::ItemFetchJob(items, this);
 }
 
+void KMCommand::fetchMessages(const Akonadi::Item::List &ids)
+{
+    ++KMCommand::mCountJobs;
+    Akonadi::ItemFetchJob *fetch = createFetchJob(ids);
+    mFetchScope.fetchAttribute<Akonadi::MDNStateAttribute>();
+    fetch->setFetchScope(mFetchScope);
+    connect(fetch, &Akonadi::ItemFetchJob::itemsReceived, this, &KMCommand::slotMsgTransfered);
+    connect(fetch, &Akonadi::ItemFetchJob::result, this, &KMCommand::slotJobFinished);
+}
+
 void KMCommand::transferSelectedMsgs()
 {
     // make sure no other transfer is active
@@ -304,12 +310,19 @@ void KMCommand::transferSelectedMsgs()
     // TODO once the message list is based on ETM and we get the more advanced caching we need to make that check a bit more clever
     if (!mFetchScope.isEmpty()) {
         complete = false;
-        ++KMCommand::mCountJobs;
-        Akonadi::ItemFetchJob *fetch = createFetchJob(mMsgList);
-        mFetchScope.fetchAttribute<Akonadi::MDNStateAttribute>();
-        fetch->setFetchScope(mFetchScope);
-        connect(fetch, &Akonadi::ItemFetchJob::itemsReceived, this, &KMCommand::slotMsgTransfered);
-        connect(fetch, &Akonadi::ItemFetchJob::result, this, &KMCommand::slotJobFinished);
+        Akonadi::Item::List ids;
+        ids.reserve(100);
+        for (const Akonadi::Item &item : mMsgList) {
+            ids.append(item);
+            if (ids.count() >= 100) {
+                fetchMessages(ids);
+                ids.clear();
+                ids.reserve(100);
+            }
+        }
+        if (!ids.isEmpty()) {
+            fetchMessages(ids);
+        }
     } else {
         // no need to fetch anything
         if (!mMsgList.isEmpty()) {
@@ -349,7 +362,7 @@ void KMCommand::slotJobFinished()
         return;
     }
 
-    if (mCountMsgs > mRetrievedMsgs.count()) {
+    if (KMCommand::mCountJobs == 0 && (mCountMsgs > mRetrievedMsgs.count())) {
         // the message wasn't retrieved before => error
         if (mProgressDialog.data()) {
             mProgressDialog.data()->hide();
@@ -360,7 +373,7 @@ void KMCommand::slotJobFinished()
     // update the progressbar
     if (mProgressDialog.data()) {
         mProgressDialog.data()->setLabelText(
-            i18np("Please wait while the message is transferred", "Please wait while the %1 messages are transferred", KMCommand::mCountJobs));
+            i18np("Please wait while the message is transferred", "Please wait while the %1 messages are transferred", mCountMsgs));
     }
     if (KMCommand::mCountJobs == 0) {
         // all done
@@ -1903,7 +1916,7 @@ KMCommand::Result KMShareImageCommand::execute()
     KMail::Composer::AttachmentInfo info;
     info.url = mUrl;
     info.comment = i18n("Image");
-    infoList.append(info);
+    infoList.append(std::move(info));
     win->addAttachment(infoList, false);
     win->show();
     return OK;
