@@ -63,6 +63,7 @@ class ManageShowCollectionProperties;
 class KActionMenuTransport;
 class KActionMenuAccount;
 class ZoomLabelWidget;
+class HistoryClosedReaderMenu;
 
 namespace KIO
 {
@@ -540,6 +541,8 @@ private:
     void slotClearFolder();
     void slotClearCacheDone();
     void slotClearFolderAndSubFolders();
+    void slotRestoreClosedMessage(Akonadi::Item::Id id);
+    void slotHistoryClosedReaderChanged();
 
     // Message actions
     QAction *mDeleteAction = nullptr;
@@ -666,4 +669,5 @@ private:
     KMailPluginCheckBeforeDeletingManagerInterface *mPluginCheckBeforeDeletingManagerInterface = nullptr;
     CollectionSwitcherTreeViewManager *const mCollectionSwitcherTreeViewManager;
     QAction *mClearFolderCacheAction = nullptr;
+    HistoryClosedReaderMenu *mRestoreClosedMessageMenu = nullptr;
 };
